(function (global, factory) {
    typeof exports === 'object' && typeof module !== 'undefined' ? module.exports = factory() :
    typeof define === 'function' && define.amd ? define(factory) :
    (global = global || self, global.Easyforms = factory());
}(this, (function () { 'use strict';

    function noop() { }
    function assign(tar, src) {
        // @ts-ignore
        for (const k in src)
            tar[k] = src[k];
        return tar;
    }
    function run(fn) {
        return fn();
    }
    function blank_object() {
        return Object.create(null);
    }
    function run_all(fns) {
        fns.forEach(run);
    }
    function is_function(thing) {
        return typeof thing === 'function';
    }
    function safe_not_equal(a, b) {
        return a != a ? b == b : a !== b || ((a && typeof a === 'object') || typeof a === 'function');
    }
    function subscribe(store, callback) {
        const unsub = store.subscribe(callback);
        return unsub.unsubscribe ? () => unsub.unsubscribe() : unsub;
    }
    function component_subscribe(component, store, callback) {
        component.$$.on_destroy.push(subscribe(store, callback));
    }
    function create_slot(definition, ctx, $$scope, fn) {
        if (definition) {
            const slot_ctx = get_slot_context(definition, ctx, $$scope, fn);
            return definition[0](slot_ctx);
        }
    }
    function get_slot_context(definition, ctx, $$scope, fn) {
        return definition[1] && fn
            ? assign($$scope.ctx.slice(), definition[1](fn(ctx)))
            : $$scope.ctx;
    }
    function get_slot_changes(definition, $$scope, dirty, fn) {
        return definition[2] && fn
            ? $$scope.dirty | definition[2](fn(dirty))
            : $$scope.dirty;
    }

    function append(target, node) {
        target.appendChild(node);
    }
    function insert(target, node, anchor) {
        target.insertBefore(node, anchor || null);
    }
    function detach(node) {
        node.parentNode.removeChild(node);
    }
    function destroy_each(iterations, detaching) {
        for (let i = 0; i < iterations.length; i += 1) {
            if (iterations[i])
                iterations[i].d(detaching);
        }
    }
    function element(name) {
        return document.createElement(name);
    }
    function text(data) {
        return document.createTextNode(data);
    }
    function space() {
        return text(' ');
    }
    function empty() {
        return text('');
    }
    function listen(node, event, handler, options) {
        node.addEventListener(event, handler, options);
        return () => node.removeEventListener(event, handler, options);
    }
    function prevent_default(fn) {
        return function (event) {
            event.preventDefault();
            // @ts-ignore
            return fn.call(this, event);
        };
    }
    function attr(node, attribute, value) {
        if (value == null)
            node.removeAttribute(attribute);
        else if (node.getAttribute(attribute) !== value)
            node.setAttribute(attribute, value);
    }
    function children(element) {
        return Array.from(element.childNodes);
    }
    function set_data(text, data) {
        data = '' + data;
        if (text.data !== data)
            text.data = data;
    }
    function set_style(node, key, value, important) {
        node.style.setProperty(key, value, important ? 'important' : '');
    }
    function toggle_class(element, name, toggle) {
        element.classList[toggle ? 'add' : 'remove'](name);
    }
    function custom_event(type, detail) {
        const e = document.createEvent('CustomEvent');
        e.initCustomEvent(type, false, false, detail);
        return e;
    }

    let current_component;
    function set_current_component(component) {
        current_component = component;
    }
    function get_current_component() {
        if (!current_component)
            throw new Error(`Function called outside component initialization`);
        return current_component;
    }
    function onMount(fn) {
        get_current_component().$$.on_mount.push(fn);
    }
    function createEventDispatcher() {
        const component = get_current_component();
        return (type, detail) => {
            const callbacks = component.$$.callbacks[type];
            if (callbacks) {
                // TODO are there situations where events could be dispatched
                // in a server (non-DOM) environment?
                const event = custom_event(type, detail);
                callbacks.slice().forEach(fn => {
                    fn.call(component, event);
                });
            }
        };
    }

    const dirty_components = [];
    const binding_callbacks = [];
    const render_callbacks = [];
    const flush_callbacks = [];
    const resolved_promise = Promise.resolve();
    let update_scheduled = false;
    function schedule_update() {
        if (!update_scheduled) {
            update_scheduled = true;
            resolved_promise.then(flush);
        }
    }
    function add_render_callback(fn) {
        render_callbacks.push(fn);
    }
    function flush() {
        const seen_callbacks = new Set();
        do {
            // first, call beforeUpdate functions
            // and update components
            while (dirty_components.length) {
                const component = dirty_components.shift();
                set_current_component(component);
                update(component.$$);
            }
            while (binding_callbacks.length)
                binding_callbacks.pop()();
            // then, once components are updated, call
            // afterUpdate functions. This may cause
            // subsequent updates...
            for (let i = 0; i < render_callbacks.length; i += 1) {
                const callback = render_callbacks[i];
                if (!seen_callbacks.has(callback)) {
                    callback();
                    // ...so guard against infinite loops
                    seen_callbacks.add(callback);
                }
            }
            render_callbacks.length = 0;
        } while (dirty_components.length);
        while (flush_callbacks.length) {
            flush_callbacks.pop()();
        }
        update_scheduled = false;
    }
    function update($$) {
        if ($$.fragment !== null) {
            $$.update();
            run_all($$.before_update);
            $$.fragment && $$.fragment.p($$.ctx, $$.dirty);
            $$.dirty = [-1];
            $$.after_update.forEach(add_render_callback);
        }
    }
    const outroing = new Set();
    let outros;
    function group_outros() {
        outros = {
            r: 0,
            c: [],
            p: outros // parent group
        };
    }
    function check_outros() {
        if (!outros.r) {
            run_all(outros.c);
        }
        outros = outros.p;
    }
    function transition_in(block, local) {
        if (block && block.i) {
            outroing.delete(block);
            block.i(local);
        }
    }
    function transition_out(block, local, detach, callback) {
        if (block && block.o) {
            if (outroing.has(block))
                return;
            outroing.add(block);
            outros.c.push(() => {
                outroing.delete(block);
                if (callback) {
                    if (detach)
                        block.d(1);
                    callback();
                }
            });
            block.o(local);
        }
    }

    function get_spread_update(levels, updates) {
        const update = {};
        const to_null_out = {};
        const accounted_for = { $$scope: 1 };
        let i = levels.length;
        while (i--) {
            const o = levels[i];
            const n = updates[i];
            if (n) {
                for (const key in o) {
                    if (!(key in n))
                        to_null_out[key] = 1;
                }
                for (const key in n) {
                    if (!accounted_for[key]) {
                        update[key] = n[key];
                        accounted_for[key] = 1;
                    }
                }
                levels[i] = n;
            }
            else {
                for (const key in o) {
                    accounted_for[key] = 1;
                }
            }
        }
        for (const key in to_null_out) {
            if (!(key in update))
                update[key] = undefined;
        }
        return update;
    }
    function get_spread_object(spread_props) {
        return typeof spread_props === 'object' && spread_props !== null ? spread_props : {};
    }
    function create_component(block) {
        block && block.c();
    }
    function mount_component(component, target, anchor) {
        const { fragment, on_mount, on_destroy, after_update } = component.$$;
        fragment && fragment.m(target, anchor);
        // onMount happens before the initial afterUpdate
        add_render_callback(() => {
            const new_on_destroy = on_mount.map(run).filter(is_function);
            if (on_destroy) {
                on_destroy.push(...new_on_destroy);
            }
            else {
                // Edge case - component was destroyed immediately,
                // most likely as a result of a binding initialising
                run_all(new_on_destroy);
            }
            component.$$.on_mount = [];
        });
        after_update.forEach(add_render_callback);
    }
    function destroy_component(component, detaching) {
        const $$ = component.$$;
        if ($$.fragment !== null) {
            run_all($$.on_destroy);
            $$.fragment && $$.fragment.d(detaching);
            // TODO null out other refs, including component.$$ (but need to
            // preserve final state?)
            $$.on_destroy = $$.fragment = null;
            $$.ctx = [];
        }
    }
    function make_dirty(component, i) {
        if (component.$$.dirty[0] === -1) {
            dirty_components.push(component);
            schedule_update();
            component.$$.dirty.fill(0);
        }
        component.$$.dirty[(i / 31) | 0] |= (1 << (i % 31));
    }
    function init(component, options, instance, create_fragment, not_equal, props, dirty = [-1]) {
        const parent_component = current_component;
        set_current_component(component);
        const prop_values = options.props || {};
        const $$ = component.$$ = {
            fragment: null,
            ctx: null,
            // state
            props,
            update: noop,
            not_equal,
            bound: blank_object(),
            // lifecycle
            on_mount: [],
            on_destroy: [],
            before_update: [],
            after_update: [],
            context: new Map(parent_component ? parent_component.$$.context : []),
            // everything else
            callbacks: blank_object(),
            dirty
        };
        let ready = false;
        $$.ctx = instance
            ? instance(component, prop_values, (i, ret, value = ret) => {
                if ($$.ctx && not_equal($$.ctx[i], $$.ctx[i] = value)) {
                    if ($$.bound[i])
                        $$.bound[i](value);
                    if (ready)
                        make_dirty(component, i);
                }
                return ret;
            })
            : [];
        $$.update();
        ready = true;
        run_all($$.before_update);
        // `false` as a special case of no DOM component
        $$.fragment = create_fragment ? create_fragment($$.ctx) : false;
        if (options.target) {
            if (options.hydrate) {
                // eslint-disable-next-line @typescript-eslint/no-non-null-assertion
                $$.fragment && $$.fragment.l(children(options.target));
            }
            else {
                // eslint-disable-next-line @typescript-eslint/no-non-null-assertion
                $$.fragment && $$.fragment.c();
            }
            if (options.intro)
                transition_in(component.$$.fragment);
            mount_component(component, options.target, options.anchor);
            flush();
        }
        set_current_component(parent_component);
    }
    class SvelteComponent {
        $destroy() {
            destroy_component(this, 1);
            this.$destroy = noop;
        }
        $on(type, callback) {
            const callbacks = (this.$$.callbacks[type] || (this.$$.callbacks[type] = []));
            callbacks.push(callback);
            return () => {
                const index = callbacks.indexOf(callback);
                if (index !== -1)
                    callbacks.splice(index, 1);
            };
        }
        $set() {
            // overridden by instance, if it has props
        }
    }

    const subscriber_queue = [];
    /**
     * Create a `Writable` store that allows both updating and reading by subscription.
     * @param {*=}value initial value
     * @param {StartStopNotifier=}start start and stop notifications for subscriptions
     */
    function writable(value, start = noop) {
        let stop;
        const subscribers = [];
        function set(new_value) {
            if (safe_not_equal(value, new_value)) {
                value = new_value;
                if (stop) { // store is ready
                    const run_queue = !subscriber_queue.length;
                    for (let i = 0; i < subscribers.length; i += 1) {
                        const s = subscribers[i];
                        s[1]();
                        subscriber_queue.push(s, value);
                    }
                    if (run_queue) {
                        for (let i = 0; i < subscriber_queue.length; i += 2) {
                            subscriber_queue[i][0](subscriber_queue[i + 1]);
                        }
                        subscriber_queue.length = 0;
                    }
                }
            }
        }
        function update(fn) {
            set(fn(value));
        }
        function subscribe(run, invalidate = noop) {
            const subscriber = [run, invalidate];
            subscribers.push(subscriber);
            if (subscribers.length === 1) {
                stop = start(set) || noop;
            }
            run(value);
            return () => {
                const index = subscribers.indexOf(subscriber);
                if (index !== -1) {
                    subscribers.splice(index, 1);
                }
                if (subscribers.length === 0) {
                    stop();
                    stop = null;
                }
            };
        }
        return { set, update, subscribe };
    }

    function createValues() {
      const { subscribe, set, update } = writable({});

      return {
        subscribe,
        updateValue: (field, value = "") =>
          update(n => {
            return { ...n, [field]: value };
          }),
        reset: () => set({})
      };
    }

    const values = createValues();

    function createErrors() {
      const { subscribe, set, update } = writable({});

      return {
        subscribe,
        updateError: (field, value = "") =>
          update(n => {
            return { ...n, [field]: value };
          }),
        reset: () => set({})
      };
    }

    const errors = createErrors();

    function createTouched() {
      const { subscribe, set, update } = writable({});

      return {
        subscribe,
        updateTouched: (field, value = true) =>
          update(n => {
            return { ...n, [field]: value };
          }),
        reset: () => set({})
      };
    }

    const touched = createTouched();

    function autoresize(node) {
      const div = document.createElement("div");
      div.style.display = "block";
      div.style.position = "relative";

      const sizer = document.createElement("div");
      const style = getComputedStyle(node);
      Object.assign(sizer.style, {
        fontFamily: style.fontFamily,
        fontSize: style.fontSize,
        paddingTop: style.paddingTop,
        paddingLeft: style.paddingLeft,
        paddingBottom: style.paddingBottom,
        paddingRight: style.paddingRight,
        borderTopWidth: style.borderTopWidth,
        borderLeftWidth: style.borderLeftWidth,
        borderBottomWidth: style.borderBottomWidth,
        borderRightWidth: style.borderRightWidth,
        borderTopStyle: style.borderTopStyle,
        borderLeftStyle: style.borderLeftStyle,
        borderBottomStyle: style.borderBottomStyle,
        borderRightStyle: style.borderRightStyle,
        lineHeight: style.lineHeight,
        boxSizing: style.boxSizing,
        position: "relative",
        whiteSpace: "pre",
        visibility: "hidden"
      });

      Object.assign(node.style, {
        position: "absolute",
        left: 0,
        top: 0,
        width: "100%",
        height: "100%",
        resize: "none"
      });

      div.appendChild(sizer);
      node.parentNode.insertBefore(div, node);
      div.appendChild(node);

      function handleChange() {
        sizer.innerHTML = node.value + " ";
      }

      handleChange();
      node.addEventListener("input", handleChange);

      return {
        destroy() {
          node.removeEventListener("input", handleChange);
        }
      };
    }

    /* src/components/Input.svelte generated by Svelte v3.16.0 */

    function add_css() {
    	var style = element("style");
    	style.id = "svelte-5hmhiz-style";
    	style.textContent = "label.svelte-5hmhiz{display:grid;grid-gap:5px;grid-template-columns:1fr}input.svelte-5hmhiz,textarea.svelte-5hmhiz{box-sizing:border-box;border:4px solid #cdd7d6;border-radius:10px;font-size:15px;padding:15px}input.svelte-5hmhiz::placeholder,textarea.svelte-5hmhiz::placeholder{font-style:bold;color:rgba(0, 0, 0, 0.4)}input.svelte-5hmhiz:focus,textarea.svelte-5hmhiz:focus{border:4px solid #140f2d}.full.svelte-5hmhiz{grid-column:-1 / 1}.error.svelte-5hmhiz{border:4px solid red}.error-container.svelte-5hmhiz{font-size:10px;color:red}";
    	append(document.head, style);
    }

    // (85:2) {:else}
    function create_else_block(ctx) {
    	let input;
    	let input_value_value;
    	let dispose;

    	return {
    		c() {
    			input = element("input");
    			set_style(input, "font-family", /*font*/ ctx[9]);
    			attr(input, "type", /*type*/ ctx[3]);
    			attr(input, "name", /*name*/ ctx[2]);
    			attr(input, "placeholder", /*placeholder*/ ctx[0]);
    			input.value = input_value_value = /*$values*/ ctx[10][/*name*/ ctx[2]] || /*initialValue*/ ctx[4];
    			attr(input, "class", "svelte-5hmhiz");
    			toggle_class(input, "error", /*$errors*/ ctx[11][/*name*/ ctx[2]] && /*$touched*/ ctx[12][/*name*/ ctx[2]]);

    			dispose = [
    				listen(input, "keyup", /*onChange*/ ctx[13]),
    				listen(input, "change", /*onChange*/ ctx[13]),
    				listen(input, "blur", /*onBlur*/ ctx[14])
    			];
    		},
    		m(target, anchor) {
    			insert(target, input, anchor);
    		},
    		p(ctx, dirty) {
    			if (dirty & /*font*/ 512) {
    				set_style(input, "font-family", /*font*/ ctx[9]);
    			}

    			if (dirty & /*type*/ 8) {
    				attr(input, "type", /*type*/ ctx[3]);
    			}

    			if (dirty & /*name*/ 4) {
    				attr(input, "name", /*name*/ ctx[2]);
    			}

    			if (dirty & /*placeholder*/ 1) {
    				attr(input, "placeholder", /*placeholder*/ ctx[0]);
    			}

    			if (dirty & /*$values, name, initialValue*/ 1044 && input_value_value !== (input_value_value = /*$values*/ ctx[10][/*name*/ ctx[2]] || /*initialValue*/ ctx[4])) {
    				input.value = input_value_value;
    			}

    			if (dirty & /*$errors, name, $touched*/ 6148) {
    				toggle_class(input, "error", /*$errors*/ ctx[11][/*name*/ ctx[2]] && /*$touched*/ ctx[12][/*name*/ ctx[2]]);
    			}
    		},
    		d(detaching) {
    			if (detaching) detach(input);
    			run_all(dispose);
    		}
    	};
    }

    // (72:2) {#if multiline}
    function create_if_block_1(ctx) {
    	let div;
    	let textarea;
    	let textarea_value_value;
    	let autoresize_action;
    	let dispose;

    	return {
    		c() {
    			div = element("div");
    			textarea = element("textarea");
    			set_style(textarea, "min-height", /*textareaHeight*/ ctx[8]);
    			set_style(textarea, "font-family", /*font*/ ctx[9]);
    			textarea.value = textarea_value_value = /*$values*/ ctx[10][/*name*/ ctx[2]] || /*initialValue*/ ctx[4];
    			attr(textarea, "name", /*name*/ ctx[2]);
    			attr(textarea, "placeholder", /*placeholder*/ ctx[0]);
    			attr(textarea, "class", "svelte-5hmhiz");
    			toggle_class(textarea, "error", /*$errors*/ ctx[11][/*name*/ ctx[2]] && /*$touched*/ ctx[12][/*name*/ ctx[2]]);
    			set_style(div, "min-height", /*textareaHeight*/ ctx[8]);

    			dispose = [
    				listen(textarea, "keyup", /*onChange*/ ctx[13]),
    				listen(textarea, "change", /*onChange*/ ctx[13]),
    				listen(textarea, "blur", /*onBlur*/ ctx[14])
    			];
    		},
    		m(target, anchor) {
    			insert(target, div, anchor);
    			append(div, textarea);
    			autoresize_action = autoresize.call(null, textarea) || ({});
    		},
    		p(ctx, dirty) {
    			if (dirty & /*textareaHeight*/ 256) {
    				set_style(textarea, "min-height", /*textareaHeight*/ ctx[8]);
    			}

    			if (dirty & /*font*/ 512) {
    				set_style(textarea, "font-family", /*font*/ ctx[9]);
    			}

    			if (dirty & /*$values, name, initialValue*/ 1044 && textarea_value_value !== (textarea_value_value = /*$values*/ ctx[10][/*name*/ ctx[2]] || /*initialValue*/ ctx[4])) {
    				textarea.value = textarea_value_value;
    			}

    			if (dirty & /*name*/ 4) {
    				attr(textarea, "name", /*name*/ ctx[2]);
    			}

    			if (dirty & /*placeholder*/ 1) {
    				attr(textarea, "placeholder", /*placeholder*/ ctx[0]);
    			}

    			if (dirty & /*$errors, name, $touched*/ 6148) {
    				toggle_class(textarea, "error", /*$errors*/ ctx[11][/*name*/ ctx[2]] && /*$touched*/ ctx[12][/*name*/ ctx[2]]);
    			}

    			if (dirty & /*textareaHeight*/ 256) {
    				set_style(div, "min-height", /*textareaHeight*/ ctx[8]);
    			}
    		},
    		d(detaching) {
    			if (detaching) detach(div);
    			if (autoresize_action && is_function(autoresize_action.destroy)) autoresize_action.destroy();
    			run_all(dispose);
    		}
    	};
    }

    // (97:2) {#if $errors[name] && $touched[name] && errorMessage}
    function create_if_block(ctx) {
    	let div;
    	let t;

    	return {
    		c() {
    			div = element("div");
    			t = text(/*errorMessage*/ ctx[6]);
    			attr(div, "class", "error-container svelte-5hmhiz");
    		},
    		m(target, anchor) {
    			insert(target, div, anchor);
    			append(div, t);
    		},
    		p(ctx, dirty) {
    			if (dirty & /*errorMessage*/ 64) set_data(t, /*errorMessage*/ ctx[6]);
    		},
    		d(detaching) {
    			if (detaching) detach(div);
    		}
    	};
    }

    function create_fragment(ctx) {
    	let label;
    	let t0;
    	let t1;
    	let t2;

    	function select_block_type(ctx, dirty) {
    		if (/*multiline*/ ctx[7]) return create_if_block_1;
    		return create_else_block;
    	}

    	let current_block_type = select_block_type(ctx);
    	let if_block0 = current_block_type(ctx);
    	let if_block1 = /*$errors*/ ctx[11][/*name*/ ctx[2]] && /*$touched*/ ctx[12][/*name*/ ctx[2]] && /*errorMessage*/ ctx[6] && create_if_block(ctx);

    	return {
    		c() {
    			label = element("label");
    			t0 = text(/*title*/ ctx[5]);
    			t1 = space();
    			if_block0.c();
    			t2 = space();
    			if (if_block1) if_block1.c();
    			set_style(label, "font-family", /*font*/ ctx[9]);
    			attr(label, "class", "svelte-5hmhiz");
    			toggle_class(label, "full", /*full*/ ctx[1]);
    		},
    		m(target, anchor) {
    			insert(target, label, anchor);
    			append(label, t0);
    			append(label, t1);
    			if_block0.m(label, null);
    			append(label, t2);
    			if (if_block1) if_block1.m(label, null);
    		},
    		p(ctx, [dirty]) {
    			if (dirty & /*title*/ 32) set_data(t0, /*title*/ ctx[5]);

    			if (current_block_type === (current_block_type = select_block_type(ctx)) && if_block0) {
    				if_block0.p(ctx, dirty);
    			} else {
    				if_block0.d(1);
    				if_block0 = current_block_type(ctx);

    				if (if_block0) {
    					if_block0.c();
    					if_block0.m(label, t2);
    				}
    			}

    			if (/*$errors*/ ctx[11][/*name*/ ctx[2]] && /*$touched*/ ctx[12][/*name*/ ctx[2]] && /*errorMessage*/ ctx[6]) {
    				if (if_block1) {
    					if_block1.p(ctx, dirty);
    				} else {
    					if_block1 = create_if_block(ctx);
    					if_block1.c();
    					if_block1.m(label, null);
    				}
    			} else if (if_block1) {
    				if_block1.d(1);
    				if_block1 = null;
    			}

    			if (dirty & /*font*/ 512) {
    				set_style(label, "font-family", /*font*/ ctx[9]);
    			}

    			if (dirty & /*full*/ 2) {
    				toggle_class(label, "full", /*full*/ ctx[1]);
    			}
    		},
    		i: noop,
    		o: noop,
    		d(detaching) {
    			if (detaching) detach(label);
    			if_block0.d();
    			if (if_block1) if_block1.d();
    		}
    	};
    }

    function instance($$self, $$props, $$invalidate) {
    	let $values;
    	let $errors;
    	let $touched;
    	component_subscribe($$self, values, $$value => $$invalidate(10, $values = $$value));
    	component_subscribe($$self, errors, $$value => $$invalidate(11, $errors = $$value));
    	component_subscribe($$self, touched, $$value => $$invalidate(12, $touched = $$value));
    	let { placeholder = "" } = $$props;
    	let { full = false } = $$props;
    	let { name = "" } = $$props;
    	let { type = "text" } = $$props;
    	let { initialValue = "" } = $$props;
    	let { title = "" } = $$props;
    	let { validator = () => true } = $$props;
    	let { errorMessage = "" } = $$props;
    	let { multiline } = $$props;
    	let { textareaHeight = "150px" } = $$props;
    	let { font = "Work Sans" } = $$props;

    	onMount(() => {
    		values.updateValue(name, initialValue);
    		errors.updateError(name, !validator(initialValue));
    		touched.updateTouched(name, false);
    	});

    	function onChange(event) {
    		values.updateValue(name, event.target.value);
    		errors.updateError(name, !validator(event.target.value));
    	}

    	function onBlur(event) {
    		values.updateValue(name, event.target.value);
    		touched.updateTouched(name);
    	}

    	$$self.$set = $$props => {
    		if ("placeholder" in $$props) $$invalidate(0, placeholder = $$props.placeholder);
    		if ("full" in $$props) $$invalidate(1, full = $$props.full);
    		if ("name" in $$props) $$invalidate(2, name = $$props.name);
    		if ("type" in $$props) $$invalidate(3, type = $$props.type);
    		if ("initialValue" in $$props) $$invalidate(4, initialValue = $$props.initialValue);
    		if ("title" in $$props) $$invalidate(5, title = $$props.title);
    		if ("validator" in $$props) $$invalidate(15, validator = $$props.validator);
    		if ("errorMessage" in $$props) $$invalidate(6, errorMessage = $$props.errorMessage);
    		if ("multiline" in $$props) $$invalidate(7, multiline = $$props.multiline);
    		if ("textareaHeight" in $$props) $$invalidate(8, textareaHeight = $$props.textareaHeight);
    		if ("font" in $$props) $$invalidate(9, font = $$props.font);
    	};

    	$$self.$$.update = () => {
    		if ($$self.$$.dirty & /*name, validator, $values*/ 33796) {
    			 errors.updateError(name, !validator($values[name]));
    		}
    	};

    	return [
    		placeholder,
    		full,
    		name,
    		type,
    		initialValue,
    		title,
    		errorMessage,
    		multiline,
    		textareaHeight,
    		font,
    		$values,
    		$errors,
    		$touched,
    		onChange,
    		onBlur,
    		validator
    	];
    }

    class Input extends SvelteComponent {
    	constructor(options) {
    		super();
    		if (!document.getElementById("svelte-5hmhiz-style")) add_css();

    		init(this, options, instance, create_fragment, safe_not_equal, {
    			placeholder: 0,
    			full: 1,
    			name: 2,
    			type: 3,
    			initialValue: 4,
    			title: 5,
    			validator: 15,
    			errorMessage: 6,
    			multiline: 7,
    			textareaHeight: 8,
    			font: 9
    		});
    	}
    }

    /* src/components/Button.svelte generated by Svelte v3.16.0 */

    function add_css$1() {
    	var style = element("style");
    	style.id = "svelte-1t8o73s-style";
    	style.textContent = "button.svelte-1t8o73s{cursor:pointer;border:none;border-radius:10px;padding:10px 20px}.big.svelte-1t8o73s{padding:20px 35px}.primary.svelte-1t8o73s{background:#d62246;border:solid #d62246 2px;color:white}.primary.svelte-1t8o73s:hover{background:#b41a39;border:solid #b41a39 2px}.primaryOutline.svelte-1t8o73s{background:none;border:solid #d62246 2px;color:#d62246}.primaryOutline.svelte-1t8o73s:hover{color:#b41a39;border:solid #b41a39 2px}";
    	append(document.head, style);
    }

    function create_fragment$1(ctx) {
    	let button;
    	let t;
    	let current;
    	let dispose;
    	const default_slot_template = /*$$slots*/ ctx[5].default;
    	const default_slot = create_slot(default_slot_template, ctx, /*$$scope*/ ctx[4], null);

    	return {
    		c() {
    			button = element("button");

    			if (!default_slot) {
    				t = text("Default");
    			}

    			if (default_slot) default_slot.c();
    			attr(button, "class", "svelte-1t8o73s");
    			toggle_class(button, "primary", /*primary*/ ctx[0]);
    			toggle_class(button, "primaryOutline", /*primaryOutline*/ ctx[1]);
    			toggle_class(button, "big", /*big*/ ctx[2]);
    			dispose = listen(button, "click", prevent_default(/*click*/ ctx[3]));
    		},
    		m(target, anchor) {
    			insert(target, button, anchor);

    			if (!default_slot) {
    				append(button, t);
    			}

    			if (default_slot) {
    				default_slot.m(button, null);
    			}

    			current = true;
    		},
    		p(ctx, [dirty]) {
    			if (default_slot && default_slot.p && dirty & /*$$scope*/ 16) {
    				default_slot.p(get_slot_context(default_slot_template, ctx, /*$$scope*/ ctx[4], null), get_slot_changes(default_slot_template, /*$$scope*/ ctx[4], dirty, null));
    			}

    			if (dirty & /*primary*/ 1) {
    				toggle_class(button, "primary", /*primary*/ ctx[0]);
    			}

    			if (dirty & /*primaryOutline*/ 2) {
    				toggle_class(button, "primaryOutline", /*primaryOutline*/ ctx[1]);
    			}

    			if (dirty & /*big*/ 4) {
    				toggle_class(button, "big", /*big*/ ctx[2]);
    			}
    		},
    		i(local) {
    			if (current) return;
    			transition_in(default_slot, local);
    			current = true;
    		},
    		o(local) {
    			transition_out(default_slot, local);
    			current = false;
    		},
    		d(detaching) {
    			if (detaching) detach(button);
    			if (default_slot) default_slot.d(detaching);
    			dispose();
    		}
    	};
    }

    function instance$1($$self, $$props, $$invalidate) {
    	let { primary } = $$props;
    	let { primaryOutline } = $$props;
    	let { big } = $$props;
    	let { click } = $$props;
    	let { $$slots = {}, $$scope } = $$props;

    	$$self.$set = $$props => {
    		if ("primary" in $$props) $$invalidate(0, primary = $$props.primary);
    		if ("primaryOutline" in $$props) $$invalidate(1, primaryOutline = $$props.primaryOutline);
    		if ("big" in $$props) $$invalidate(2, big = $$props.big);
    		if ("click" in $$props) $$invalidate(3, click = $$props.click);
    		if ("$$scope" in $$props) $$invalidate(4, $$scope = $$props.$$scope);
    	};

    	return [primary, primaryOutline, big, click, $$scope, $$slots];
    }

    class Button extends SvelteComponent {
    	constructor(options) {
    		super();
    		if (!document.getElementById("svelte-1t8o73s-style")) add_css$1();

    		init(this, options, instance$1, create_fragment$1, safe_not_equal, {
    			primary: 0,
    			primaryOutline: 1,
    			big: 2,
    			click: 3
    		});
    	}
    }

    /* src/index.svelte generated by Svelte v3.16.0 */

    function add_css$2() {
    	var style = element("style");
    	style.id = "svelte-l1056w-style";
    	style.textContent = "form.svelte-l1056w{display:grid;grid-gap:15px;grid-template-columns:repeat(auto-fill, minmax(250px, 1fr))}span.svelte-l1056w{font-size:20px;font-family:\"Work Sans\";font-weight:bold}.button-container.svelte-l1056w{margin-top:10px;display:grid;grid-gap:15px;grid-column:-1 / 1}";
    	append(document.head, style);
    }

    function get_each_context(ctx, list, i) {
    	const child_ctx = ctx.slice();
    	child_ctx[12] = list[i];
    	return child_ctx;
    }

    // (60:2) {#each inputs as input}
    function create_each_block(ctx) {
    	let current;
    	const input_spread_levels = [/*input*/ ctx[12], { font: /*font*/ ctx[4] }];
    	let input_props = {};

    	for (let i = 0; i < input_spread_levels.length; i += 1) {
    		input_props = assign(input_props, input_spread_levels[i]);
    	}

    	const input = new Input({ props: input_props });

    	return {
    		c() {
    			create_component(input.$$.fragment);
    		},
    		m(target, anchor) {
    			mount_component(input, target, anchor);
    			current = true;
    		},
    		p(ctx, dirty) {
    			const input_changes = dirty & /*inputs, font*/ 17
    			? get_spread_update(input_spread_levels, [
    					dirty & /*inputs*/ 1 && get_spread_object(/*input*/ ctx[12]),
    					dirty & /*font*/ 16 && ({ font: /*font*/ ctx[4] })
    				])
    			: {};

    			input.$set(input_changes);
    		},
    		i(local) {
    			if (current) return;
    			transition_in(input.$$.fragment, local);
    			current = true;
    		},
    		o(local) {
    			transition_out(input.$$.fragment, local);
    			current = false;
    		},
    		d(detaching) {
    			destroy_component(input, detaching);
    		}
    	};
    }

    // (64:4) <Button primary click={handleSubmit}>
    function create_default_slot_1(ctx) {
    	let span;
    	let t;

    	return {
    		c() {
    			span = element("span");
    			t = text(/*buttonText*/ ctx[1]);
    			attr(span, "class", "svelte-l1056w");
    		},
    		m(target, anchor) {
    			insert(target, span, anchor);
    			append(span, t);
    		},
    		p(ctx, dirty) {
    			if (dirty & /*buttonText*/ 2) set_data(t, /*buttonText*/ ctx[1]);
    		},
    		d(detaching) {
    			if (detaching) detach(span);
    		}
    	};
    }

    // (67:4) {#if reset}
    function create_if_block_1$1(ctx) {
    	let current;

    	const button = new Button({
    			props: {
    				primaryOutline: true,
    				click: /*resetForm*/ ctx[10],
    				$$slots: { default: [create_default_slot] },
    				$$scope: { ctx }
    			}
    		});

    	return {
    		c() {
    			create_component(button.$$.fragment);
    		},
    		m(target, anchor) {
    			mount_component(button, target, anchor);
    			current = true;
    		},
    		p(ctx, dirty) {
    			const button_changes = {};

    			if (dirty & /*$$scope, resetText*/ 32772) {
    				button_changes.$$scope = { dirty, ctx };
    			}

    			button.$set(button_changes);
    		},
    		i(local) {
    			if (current) return;
    			transition_in(button.$$.fragment, local);
    			current = true;
    		},
    		o(local) {
    			transition_out(button.$$.fragment, local);
    			current = false;
    		},
    		d(detaching) {
    			destroy_component(button, detaching);
    		}
    	};
    }

    // (68:6) <Button primaryOutline click={resetForm}>
    function create_default_slot(ctx) {
    	let span;
    	let t;

    	return {
    		c() {
    			span = element("span");
    			t = text(/*resetText*/ ctx[2]);
    			attr(span, "class", "svelte-l1056w");
    		},
    		m(target, anchor) {
    			insert(target, span, anchor);
    			append(span, t);
    		},
    		p(ctx, dirty) {
    			if (dirty & /*resetText*/ 4) set_data(t, /*resetText*/ ctx[2]);
    		},
    		d(detaching) {
    			if (detaching) detach(span);
    		}
    	};
    }

    // (75:0) {#if debug}
    function create_if_block$1(ctx) {
    	let h30;
    	let t1;
    	let pre0;
    	let t2_value = JSON.stringify(/*$values*/ ctx[7], null, 2) + "";
    	let t2;
    	let t3;
    	let h31;
    	let t5;
    	let pre1;
    	let t6_value = JSON.stringify(/*$touched*/ ctx[8], null, 2) + "";
    	let t6;
    	let t7;
    	let h32;
    	let t9;
    	let pre2;
    	let t10_value = JSON.stringify(/*$errors*/ ctx[6], null, 2) + "";
    	let t10;

    	return {
    		c() {
    			h30 = element("h3");
    			h30.textContent = "Values";
    			t1 = space();
    			pre0 = element("pre");
    			t2 = text(t2_value);
    			t3 = space();
    			h31 = element("h3");
    			h31.textContent = "Touched";
    			t5 = space();
    			pre1 = element("pre");
    			t6 = text(t6_value);
    			t7 = space();
    			h32 = element("h3");
    			h32.textContent = "Errors";
    			t9 = space();
    			pre2 = element("pre");
    			t10 = text(t10_value);
    		},
    		m(target, anchor) {
    			insert(target, h30, anchor);
    			insert(target, t1, anchor);
    			insert(target, pre0, anchor);
    			append(pre0, t2);
    			insert(target, t3, anchor);
    			insert(target, h31, anchor);
    			insert(target, t5, anchor);
    			insert(target, pre1, anchor);
    			append(pre1, t6);
    			insert(target, t7, anchor);
    			insert(target, h32, anchor);
    			insert(target, t9, anchor);
    			insert(target, pre2, anchor);
    			append(pre2, t10);
    		},
    		p(ctx, dirty) {
    			if (dirty & /*$values*/ 128 && t2_value !== (t2_value = JSON.stringify(/*$values*/ ctx[7], null, 2) + "")) set_data(t2, t2_value);
    			if (dirty & /*$touched*/ 256 && t6_value !== (t6_value = JSON.stringify(/*$touched*/ ctx[8], null, 2) + "")) set_data(t6, t6_value);
    			if (dirty & /*$errors*/ 64 && t10_value !== (t10_value = JSON.stringify(/*$errors*/ ctx[6], null, 2) + "")) set_data(t10, t10_value);
    		},
    		d(detaching) {
    			if (detaching) detach(h30);
    			if (detaching) detach(t1);
    			if (detaching) detach(pre0);
    			if (detaching) detach(t3);
    			if (detaching) detach(h31);
    			if (detaching) detach(t5);
    			if (detaching) detach(pre1);
    			if (detaching) detach(t7);
    			if (detaching) detach(h32);
    			if (detaching) detach(t9);
    			if (detaching) detach(pre2);
    		}
    	};
    }

    function create_fragment$2(ctx) {
    	let form;
    	let t0;
    	let div;
    	let t1;
    	let t2;
    	let if_block1_anchor;
    	let current;
    	let each_value = /*inputs*/ ctx[0];
    	let each_blocks = [];

    	for (let i = 0; i < each_value.length; i += 1) {
    		each_blocks[i] = create_each_block(get_each_context(ctx, each_value, i));
    	}

    	const out = i => transition_out(each_blocks[i], 1, 1, () => {
    		each_blocks[i] = null;
    	});

    	const button = new Button({
    			props: {
    				primary: true,
    				click: /*handleSubmit*/ ctx[9],
    				$$slots: { default: [create_default_slot_1] },
    				$$scope: { ctx }
    			}
    		});

    	let if_block0 = /*reset*/ ctx[3] && create_if_block_1$1(ctx);
    	let if_block1 = /*debug*/ ctx[5] && create_if_block$1(ctx);

    	return {
    		c() {
    			form = element("form");

    			for (let i = 0; i < each_blocks.length; i += 1) {
    				each_blocks[i].c();
    			}

    			t0 = space();
    			div = element("div");
    			create_component(button.$$.fragment);
    			t1 = space();
    			if (if_block0) if_block0.c();
    			t2 = space();
    			if (if_block1) if_block1.c();
    			if_block1_anchor = empty();
    			attr(div, "class", "button-container svelte-l1056w");
    			attr(form, "action", "");
    			attr(form, "class", "svelte-l1056w");
    		},
    		m(target, anchor) {
    			insert(target, form, anchor);

    			for (let i = 0; i < each_blocks.length; i += 1) {
    				each_blocks[i].m(form, null);
    			}

    			append(form, t0);
    			append(form, div);
    			mount_component(button, div, null);
    			append(div, t1);
    			if (if_block0) if_block0.m(div, null);
    			insert(target, t2, anchor);
    			if (if_block1) if_block1.m(target, anchor);
    			insert(target, if_block1_anchor, anchor);
    			current = true;
    		},
    		p(ctx, [dirty]) {
    			if (dirty & /*inputs, font*/ 17) {
    				each_value = /*inputs*/ ctx[0];
    				let i;

    				for (i = 0; i < each_value.length; i += 1) {
    					const child_ctx = get_each_context(ctx, each_value, i);

    					if (each_blocks[i]) {
    						each_blocks[i].p(child_ctx, dirty);
    						transition_in(each_blocks[i], 1);
    					} else {
    						each_blocks[i] = create_each_block(child_ctx);
    						each_blocks[i].c();
    						transition_in(each_blocks[i], 1);
    						each_blocks[i].m(form, t0);
    					}
    				}

    				group_outros();

    				for (i = each_value.length; i < each_blocks.length; i += 1) {
    					out(i);
    				}

    				check_outros();
    			}

    			const button_changes = {};

    			if (dirty & /*$$scope, buttonText*/ 32770) {
    				button_changes.$$scope = { dirty, ctx };
    			}

    			button.$set(button_changes);

    			if (/*reset*/ ctx[3]) {
    				if (if_block0) {
    					if_block0.p(ctx, dirty);
    					transition_in(if_block0, 1);
    				} else {
    					if_block0 = create_if_block_1$1(ctx);
    					if_block0.c();
    					transition_in(if_block0, 1);
    					if_block0.m(div, null);
    				}
    			} else if (if_block0) {
    				group_outros();

    				transition_out(if_block0, 1, 1, () => {
    					if_block0 = null;
    				});

    				check_outros();
    			}

    			if (/*debug*/ ctx[5]) {
    				if (if_block1) {
    					if_block1.p(ctx, dirty);
    				} else {
    					if_block1 = create_if_block$1(ctx);
    					if_block1.c();
    					if_block1.m(if_block1_anchor.parentNode, if_block1_anchor);
    				}
    			} else if (if_block1) {
    				if_block1.d(1);
    				if_block1 = null;
    			}
    		},
    		i(local) {
    			if (current) return;

    			for (let i = 0; i < each_value.length; i += 1) {
    				transition_in(each_blocks[i]);
    			}

    			transition_in(button.$$.fragment, local);
    			transition_in(if_block0);
    			current = true;
    		},
    		o(local) {
    			each_blocks = each_blocks.filter(Boolean);

    			for (let i = 0; i < each_blocks.length; i += 1) {
    				transition_out(each_blocks[i]);
    			}

    			transition_out(button.$$.fragment, local);
    			transition_out(if_block0);
    			current = false;
    		},
    		d(detaching) {
    			if (detaching) detach(form);
    			destroy_each(each_blocks, detaching);
    			destroy_component(button);
    			if (if_block0) if_block0.d();
    			if (detaching) detach(t2);
    			if (if_block1) if_block1.d(detaching);
    			if (detaching) detach(if_block1_anchor);
    		}
    	};
    }

    function instance$2($$self, $$props, $$invalidate) {
    	let $errors;
    	let $values;
    	let $touched;
    	component_subscribe($$self, errors, $$value => $$invalidate(6, $errors = $$value));
    	component_subscribe($$self, values, $$value => $$invalidate(7, $values = $$value));
    	component_subscribe($$self, touched, $$value => $$invalidate(8, $touched = $$value));
    	const dispatch = createEventDispatcher();
    	let { inputs = [] } = $$props;
    	let { buttonText = "SUBMIT" } = $$props;
    	let { resetText = "RESET" } = $$props;
    	let { reset } = $$props;
    	let { font } = $$props;
    	let { debug } = $$props;

    	const handleSubmit = () => {
    		const numberOfErrors = Object.keys($errors).filter(key => $errors[key]);

    		inputs.forEach(input => {
    			touched.updateTouched(input.name, true);
    		});

    		if (numberOfErrors.length === 0) {
    			console.log("SUBMITTING!");
    			resetForm();
    		} else {
    			console.log("Not submitting!");
    		}
    	};

    	const resetForm = () => {
    		inputs.forEach(input => {
    			values.updateValue(input.name);
    			touched.updateTouched(input.name, false);
    		});
    	};

    	$$self.$set = $$props => {
    		if ("inputs" in $$props) $$invalidate(0, inputs = $$props.inputs);
    		if ("buttonText" in $$props) $$invalidate(1, buttonText = $$props.buttonText);
    		if ("resetText" in $$props) $$invalidate(2, resetText = $$props.resetText);
    		if ("reset" in $$props) $$invalidate(3, reset = $$props.reset);
    		if ("font" in $$props) $$invalidate(4, font = $$props.font);
    		if ("debug" in $$props) $$invalidate(5, debug = $$props.debug);
    	};

    	return [
    		inputs,
    		buttonText,
    		resetText,
    		reset,
    		font,
    		debug,
    		$errors,
    		$values,
    		$touched,
    		handleSubmit,
    		resetForm
    	];
    }

    class Src extends SvelteComponent {
    	constructor(options) {
    		super();
    		if (!document.getElementById("svelte-l1056w-style")) add_css$2();

    		init(this, options, instance$2, create_fragment$2, safe_not_equal, {
    			inputs: 0,
    			buttonText: 1,
    			resetText: 2,
    			reset: 3,
    			font: 4,
    			debug: 5
    		});
    	}
    }

    return Src;

})));
